#ifdef __cplusplus
extern "C" {
  #define defaulttrue =true
#else
  #define defaulttrue
  #define bool       int
#endif

/* RGB to RGB and RGB from/to YCbRr (YUV) conversions written by Bisqwit
 * Copyright (C) 1992,2008 Joel Yliluoma (http://iki.fi/bisqwit/)
 *
 * Concepts:
 *    8 = RGB8 or BGR8 (with 3:3:2 palette mapping)
 *   15 = RGB15 or BGR15
 *   16 = RGB16 or BGR16
 *   24 = RGB24 or BGR24
 *   32 = RGB32 or BGR32
 * I420 = YCbCr where Y is issued for each pixel,
 *                    followed by Cr for 2x2 pixels,
 *                    followed by Cb for 2x2 pixels
 * YUY2 = YCbCr where for each pixel, Y is issued,
 *                    followed by Cr for 2x1 pixels (if even pixel)
 *                             or Cb for 2x1 pixels (if odd pixel)
 *
 * Note: Not all functions honor the swap_red_blue setting.
 */

#define RGBtoRGB_Params const void* data, unsigned char* dest, unsigned npixels

/* Anything to RGB24: */
void Convert32To24Frame(RGBtoRGB_Params);
void Convert15To24Frame(RGBtoRGB_Params, bool swap_red_blue defaulttrue);
void Convert16To24Frame(RGBtoRGB_Params, bool swap_red_blue defaulttrue);
void Convert_I420To24Frame(RGBtoRGB_Params, unsigned width, bool swap_red_blue defaulttrue); // NOTE: ignores swap_red_blue
void Convert_YUY2To24Frame(RGBtoRGB_Params, unsigned width, bool swap_red_blue defaulttrue); // NOTE: ignores swap_red_blue

/* Anything to RGB32: */
void Convert15To32Frame(RGBtoRGB_Params, bool swap_red_blue defaulttrue);
void Convert16To32Frame(RGBtoRGB_Params, bool swap_red_blue defaulttrue);
void Convert_I420To32Frame(RGBtoRGB_Params, unsigned width, bool swap_red_blue defaulttrue); // NOTE: ignores swap_red_blue
void Convert_YUY2To32Frame(RGBtoRGB_Params, unsigned width, bool swap_red_blue defaulttrue); // NOTE: ignores swap_red_blue

/* RGB24 to anything: */
void Convert24To15Frame(RGBtoRGB_Params, unsigned width);
void Convert24To16Frame(RGBtoRGB_Params, unsigned width);
void Convert24To_I420Frame(RGBtoRGB_Params, unsigned width);
void Convert24To_YUY2Frame(RGBtoRGB_Params, unsigned width);
void Convert24To8Frame(RGBtoRGB_Params, unsigned width, bool swap_red_blue defaulttrue);

/* RGB32 to anything: */
void Convert32To15Frame(RGBtoRGB_Params, unsigned width);
void Convert32To16Frame(RGBtoRGB_Params, unsigned width);
void Convert32To24Frame(RGBtoRGB_Params);
void Convert32To_I420Frame(RGBtoRGB_Params, unsigned width);
void Convert32To_YUY2Frame(RGBtoRGB_Params, unsigned width);

/* Anything to I420: */
void Convert15To_I420Frame(RGBtoRGB_Params, unsigned width);
void Convert16To_I420Frame(RGBtoRGB_Params, unsigned width);
void Convert24To_I420Frame(RGBtoRGB_Params, unsigned width);
void Convert32To_I420Frame(RGBtoRGB_Params, unsigned width);

/* Anything to YUY2: */
void Convert15To_YUY2Frame(RGBtoRGB_Params, unsigned width);
void Convert16To_YUY2Frame(RGBtoRGB_Params, unsigned width);
void Convert24To_YUY2Frame(RGBtoRGB_Params, unsigned width);
void Convert32To_YUY2Frame(RGBtoRGB_Params, unsigned width);

void Unbuild16(unsigned char* target, unsigned rgb16);

#undef RGBtoRGB_Params

#ifdef __cplusplus
}
  #undef defaulttrue
#else
  #undef defaulttrue
  #undef bool
#endif
